==========
Change Log
==========

..
    security fixed added changed deprecated removed


0.0.5 -- 2023-10-09
===================

Added
~~~~~

- CHANGELOG.rst
- _version.py

Removed
~~~~~~~

- Spurious files from source distribution.
